@@ -28,5 +28,12 @@
 
 #include "vers.h"
 
-char bootPrompt[] = "\n\nDarwin Intel boot v" I386BOOT_VERSION "\n"
-            "%dK conventional / %dK total memory\n\n";
+char bootPrompt[] = "\n\nDarwin/x86 boot v" I386BOOT_VERSION "\n"
+                    "%dK conventional / %dK extended memory\n\n"
+                    "Darwin/x86 will start up in %d seconds, or you can:\n"
+                    "  Type -v and press Return to start up Darwin/x86 with "
+                    "diagnostic messages\n"
+                    "  Type ? and press Return to learn about advanced startup "
+                    "options\n"
+                    "  Type any other character to stop Darwin/x86 from "
+                    "starting up automatically\n";
